
# q-expansion of newform 320.10.d.b, downloaded from the LMFDB on 29 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 320
weight = 10
poly_data = [903998473582229078125, -55487651630403225000, -3246773190470910215, 137934853271246136, 5448146498717098, -62475307207056, -2647129433407, 9440196504, 506716006, -394584, -38483, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[165923317755975200820774785102218992271402921332619400475, -50086496255670561030856240722420333925942337901421412500, 780954445817307335944878977966771084582831163311473785, 127334679819939769990086784730136016493083782599765671, -168735523429124464454897256915220611302320779348921, -70623087653482578155779328766776005519390227980362, -66858863442376774977163803955607776414664280939, 14726457113158236032383416347970258182920699475, 17146560027365790523422799926241218001787631, -1182671407497464518667819650968220803294868, -825244790989318081200263517599944058631, 32090362206061563356805797823460665509], 23820996729606469223063260666338807719414268667549792700], [[-165923317755975200820774785102218992271402921332619400475, 97728489714883499476982762055097949364770875236520997900, -780954445817307335944878977966771084582831163311473785, -127334679819939769990086784730136016493083782599765671, 168735523429124464454897256915220611302320779348921, 70623087653482578155779328766776005519390227980362, 66858863442376774977163803955607776414664280939, -14726457113158236032383416347970258182920699475, -17146560027365790523422799926241218001787631, 1182671407497464518667819650968220803294868, 825244790989318081200263517599944058631, -32090362206061563356805797823460665509], 23820996729606469223063260666338807719414268667549792700], [[-28997727952615703387866229079851315903248695399170278994275, 1946542156539377138996927458179164658870116477852485925475, 54103631427471057731391552790941647834528959847464861935, -3645424956496936865860950133012757725694169680993249439, -47498314675578025341942182107885954548131951197407211, 1836119713780271004099778563892197542931237041282583, 14324254670874574633882635802974019781400089278801, -369798188552132872986856401175571960134239461475, -1534243054990628341893170442777223341901737579, 29808903508082386439004658854613621240990887, 52262001278402623992137866672015987487979, -825244790989318081200263517599944058631], 11910498364803234611531630333169403859707134333774896350], [[-240318707636884390824965620265270838504916705429078188498666447750, -11537304123355968946602896386732282562749948966097454181985017735, 206420179528225722972730860374769006985219044577191212286638679, 9647494653081254337709149744250517511813224784830362089636543, -87429214741988512920374000951936599266850097356640952357363, -3506092309658348627096060955072692752565364579201008411161, 13828511550899749364729657595676874721523221845600638815, 570983576220264859431132698599795939593814280830661615, -721324681316437892413258452568299454933153574108457, -39628203614982459325014931181346782063222566449219, 8961256123743125571358347564192908132136322701, 972911205299294644830601605141750166599725957], 9982754428213919081568707134670102921503885374017594938511625], [[-125259926672410140881825712329504429540129176271540011766697716625, 13722346770411341752711049607466956737782977017202126987352050980, 104427076808641056006695501543067214348325094639337887234735513, -25500061709476294755246373913417386475318277396806233017762123, -157159487379383525109729667242691912557103428009728806528797, 15371350130770570441311233069433367079539526497437489533606, 58190841334121799207257257652275454682384746287712792001, -3305017980706708313369480166670295379974399393374467595, -7333691989067211342603030674622246449636270732731833, 268641373956415484279031633572371795927208684042904, 278601072703789949558357906327567790090301090941, -7342894942199598213839875037532932364801708697], 59896526569283514489412242808020617529023312244105569631069750], [[-670225211055666107119422377228175324094919925178206702794191798875, -56611783911900052313947903085671174631516321473536232621532142860, 3173300624480400774743161376655010733192010641486200847504875599, -28410774412505162977088052727707923250744426140290969958679675, -2292618702626869947095460742039982175147596999482502634429255, 36613949063759345737795710593215035419037434523612033220570, 580886930681159856591083988536743614890139735069873530787, -9492710738182856635548484140599239038270458688819213935, -56858478130537663248418783631986376176746976207007295, 845739568939892516901925233334155643019451277906740, 1844667491761020347613905329171928389716124397439, -24613840999166455181108979674397695094475983065], 119793053138567028978824485616041235058046624488211139262139500], [[-2552609324285661428425433551668872166844097249578297978346594799375, -185046945867574306428335704450589524272860137943693592159939680450, -825991883414382119844559644391466312785599689793027783511736925, 277960153286892872861750049620133764595575128732720689707398857, 2642775005304419167618992651768570675144217054055773633697883, -127548107835269981165372974744744001194645090394563364533844, -824663927887876444801369506755951230704896666047867659513, 24477519378378435176929779407110914840353274479166128125, 87186930417774452978416763166083962620368836058253387, -1918884568713494186658797152409022266141593861546266, -2941753611113052218163980551223757951415154095557, 52053761191280454751743509588004222926455822603], 59896526569283514489412242808020617529023312244105569631069750], [[3005096564241097625370389732770493478071504131177070111254874880875, -234193719210851864290391187624416049824825095876688518172719263945, -5400066358235797117057229921036283085908594855989216259140002452, 496128449393043627655963415191952570733355635654113011421848446, 5960559077172531025879747028093877223911200687087381269444001, -265183962977515550380488087570559443806474054596730500919673, -1969933476134169167293831299865490458579983466180402351012, 55534852620697802391210548250188974279311917650812849966, 218612179415794736593519487773666822021961293215829989, -4557815998582361426800457027102749470953616938137977, -7564955022527067213451997035941345634391324120476, 127087387076428084303449394722232421699211146358], 29948263284641757244706121404010308764511656122052784815534875], [[-26240625137427826389946812232672469313506822130135063434682668508875, 324240679284383823566480064135402203056489623615793085007999613920, 83275821079786953496820474561216891557311484009274724785021644827, 821500936533728606029986577445461872813995751240160215467901993, -45570971709208045100672154592115675944325180745351711253515575, -629582416061503388051086742598584104690898959348182503594850, 8796411596747580607852186249559963389121925956643055448071, 141113690072286680717478365863734231817340645696788346949, -605115249193379601108778829170422089912465477719224375, -11246277481743159960722685808621537223826199458441720, 13176280359160002033557100497611438979705178777427, 293911315331129952141601275482717399841114457083], 39931017712855676326274828538680411686015541496070379754046500], [[-32031052770799768658713846636956413604355857020325825304047132228875, 2193662262792483794983802571623864208858671847240960691896067090365, 47926594321031496725029119992632359586889767704794037957983467149, -3732897275836035886146053050056948698177755661325746195870766681, -29589489024348588592496476957268258649091634078244882302537423, 1798846824706113908064497275965484034463486273285484341162129, 7830705540394771575622262655995893345731319494852834866395, -347233747816575559032640599998266135337414883539151030957, -850984236802378682280480311526516340705282234224867147, 26959461662829315202211649093931765032950374156901841, 30123651451682271775867586036778195198788201641501, -720914349328033257875255901832680309563046260097], 59896526569283514489412242808020617529023312244105569631069750], [[120658533555446472943497891297793601356614940793535545223889329175625, 2691996020992799901464725506989714597739052622045423713691207646300, -509572313976228296490013404734712581236948040504597636173291876665, -14123644621364368072769510643583505121170486828420947536053209167, 255358435924294608401934763215633860133967658677708158236613437, 7381328146507754917098901578404815806608634669935316742256274, -44344099286244109949316205998191066503153198749016801796437, -1358454138150058339156331175616722952837711470907569811275, 2712899766207661264681263839244868437481946703771859293, 98603007619436008037764696917646322036406302163268236, -49454877648461961166501265569174615339860066895153, -2458214027461093831477495444500229563465207604893], 119793053138567028978824485616041235058046624488211139262139500]]

hecke_ring_character_values = [[191, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [261, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [257, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -27, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, -625, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1425, 0, -7, 0, 0, 1, 0, 0, 0, 0, 0, 0], [0, -3592, 0, 104, 0, 0, 0, 0, 2, 1, 0, 1], [0, -3400, 0, 19, 0, 0, 0, 0, -8, 1, -9, 1], [19094, 0, -559, 0, 3, 0, 19, 3, 0, 0, 0, 0], [0, -41292, 0, 994, 0, 0, 0, 0, -54, -1, -52, -3], [293875, 0, -615, 0, 27, -30, -68, 23, 0, 0, 0, 0], [0, -734225, 0, 322, 0, 0, 0, 0, -129, 152, 182, 27], [918300, 0, -2902, 0, 122, 236, -148, 28, 0, 0, 0, 0], [0, -1816600, 0, 36860, 0, 0, 0, 0, 480, 18, -1012, -132], [-7739169, 0, 29633, 0, -3, -2207, -201, -96, 0, 0, 0, 0], [0, -3927799, 0, -24927, 0, 0, 0, 0, -3165, -51, 512, -139], [-8278125, 0, 74015, 0, -664, 1305, -624, -436, 0, 0, 0, 0], [0, 6121000, 0, 56777, 0, 0, 0, 0, -7014, -1679, 1661, -479], [0, -16954748, 0, 86114, 0, 0, 0, 0, 1080, -1403, -9364, 283], [0, -7576550, 0, 570210, 0, 0, 0, 0, 15230, 420, 7570, 1320], [0, -45988475, 0, 38281, 0, 0, 0, 0, 26025, 3539, 10272, 1111], [1005850, 0, 765554, 0, 4946, 24078, 6736, 1654, 0, 0, 0, 0], [1908766, 0, 307445, 0, -2707, 150, -17161, 1893, 0, 0, 0, 0], [-56463450, 0, 1525432, 0, -1332, 13124, -18012, -618, 0, 0, 0, 0], [0, 29831371, 0, 331431, 0, 0, 0, 0, 8975, -8349, 5848, -9801], [191450666, 0, -399942, 0, 17798, -47484, 2670, 1882, 0, 0, 0, 0], [-2449444, 0, 93513, 0, -25119, -23460, 32203, -5809, 0, 0, 0, 0], [0, -383525, 0, 3409314, 0, 0, 0, 0, 35727, -12936, 53174, -23461], [-221951425, 0, 1991193, 0, 18139, 8926, -53476, -2989, 0, 0, 0, 0], [0, -3879303, 0, 2782265, 0, 0, 0, 0, -46050, 64094, -100288, 7106], [0, 553045450, 0, 408250, 0, 0, 0, 0, -175800, -10890, 18610, 15510], [285703244, 0, 2232390, 0, 22, -28550, 506, 33572, 0, 0, 0, 0], [-1254123025, 0, -975731, 0, -93009, -223592, -130244, 25059, 0, 0, 0, 0], [0, -752777058, 0, 615372, 0, 0, 0, 0, 101840, 16231, 57628, 41509], [-1496240232, 0, -6782842, 0, -162548, -299100, -50654, -5698, 0, 0, 0, 0], [0, -5555094, 0, 9072778, 0, 0, 0, 0, 582204, -117283, 421520, -22563], [0, 3041579850, 0, -15940360, 0, 0, 0, 0, -746130, 103870, -179280, -63430], [-1186840100, 0, -26862642, 0, 189482, -434794, -342188, 17368, 0, 0, 0, 0], [0, 3109760300, 0, -30458998, 0, 0, 0, 0, 441786, 137982, 14762, -68868], [0, -2530301603, 0, -788507, 0, 0, 0, 0, 308250, -120274, -36152, 10274], [-3462157075, 0, -43327577, 0, 273655, 888636, 669980, -122905, 0, 0, 0, 0], [0, 6454339000, 0, -54089068, 0, 0, 0, 0, 630276, -168134, -183244, -187184], [0, 954647782, 0, -13023774, 0, 0, 0, 0, -1895856, -276919, -147768, 4613], [0, 8045431175, 0, 7612792, 0, 0, 0, 0, 1028231, 106842, -706828, 260517], [-11410490550, 0, -41604694, 0, 192254, -463608, -1389936, -125254, 0, 0, 0, 0], [4324771570, 0, -57302437, 0, 220763, 231450, -1568551, -184437, 0, 0, 0, 0], [0, 13760157250, 0, 29498835, 0, 0, 0, 0, 958530, -39075, 1282175, 10175], [-14345306300, 0, 7066064, 0, -547644, 2159798, 1249496, 184944, 0, 0, 0, 0], [0, -2450070726, 0, -40410768, 0, 0, 0, 0, 543378, -198783, 976444, -549089], [-24245438175, 0, 59720863, 0, 1547587, 738466, 821692, -140737, 0, 0, 0, 0], [0, 6370661807, 0, 2608411, 0, 0, 0, 0, -1781930, -1278032, 770784, -22448], [0, 21063904425, 0, 246572192, 0, 0, 0, 0, -2980319, 817042, -1021628, -390533], [2903329472, 0, 19837231, 0, -104353, 2712080, 1833261, -719483, 0, 0, 0, 0], [-27570645050, 0, 73882444, 0, 2000026, 3470958, -2985284, -400476, 0, 0, 0, 0], [-8018160203, 0, 231978811, 0, -593969, 4782687, 1374125, 213644, 0, 0, 0, 0], [0, 15060863952, 0, -355701484, 0, 0, 0, 0, -423108, -37693, -1938472, 51935], [10479935192, 0, -150940484, 0, 1595342, -4571920, -2933004, 575212, 0, 0, 0, 0], [-54415112725, 0, 174372163, 0, 638758, 543441, -2773672, -606358, 0, 0, 0, 0], [0, 63350637050, 0, -101624006, 0, 0, 0, 0, 1449042, -304696, 493114, 929804], [-62274820000, 0, 183022602, 0, -605912, 4766614, 3107108, 1401362, 0, 0, 0, 0], [0, 46914957150, 0, 502362596, 0, 0, 0, 0, -7379722, 380850, -4612500, -79050], [-11032805133, 0, 315680847, 0, -22581, 2401485, -1379103, 326334, 0, 0, 0, 0], [0, -14916387721, 0, -66595365, 0, 0, 0, 0, 3314850, -618072, 1611144, 39672], [0, 71075824800, 0, 458200332, 0, 0, 0, 0, -7424874, -1571796, -2363436, -557946], [0, 13356169489, 0, 442868961, 0, 0, 0, 0, -10215525, -4099383, -3779784, 1579233], [-23858597800, 0, -473275386, 0, 2283156, 15624648, -4309204, 993394, 0, 0, 0, 0], [2148516926, 0, 18757648, 0, -2598074, 14523090, 11623288, 2727186, 0, 0, 0, 0], [0, 68857177050, 0, -966016133, 0, 0, 0, 0, -3761094, 4023761, -1970649, 443311], [0, -34908088442, 0, -761284636, 0, 0, 0, 0, 26767998, 4541233, -12548468, 2296215], [62716904346, 0, -1138352976, 0, -920718, 21248550, 10391336, 1446982, 0, 0, 0, 0], [0, -14033849785, 0, 1331403059, 0, 0, 0, 0, 6822325, 6227201, 14633848, 774749], [0, -35473215025, 0, -1016590504, 0, 0, 0, 0, 42624803, 6662506, -9750204, -2581319], [116092556162, 0, -494199974, 0, -887438, -10475220, -18432994, 2697482, 0, 0, 0, 0], [48848283950, 0, -781041352, 0, 6513902, -6425064, 10154132, 2833548, 0, 0, 0, 0], [14456585775, 0, -755953179, 0, -3659201, 14189972, -2013116, 4433651, 0, 0, 0, 0], [0, -34116372650, 0, 390961132, 0, 0, 0, 0, -30047374, 5845558, 12142628, 2628658], [0, -106800764946, 0, 1317245202, 0, 0, 0, 0, 24922326, -8199597, -13085480, -306977], [56820134025, 0, -526862901, 0, -4401015, 62791968, 19495260, 1860765, 0, 0, 0, 0], [0, -85492931750, 0, 1008555746, 0, 0, 0, 0, 24645078, -3884624, 28667666, 7596976], [0, -1980595800, 0, -1399605373, 0, 0, 0, 0, 14477036, -21506715, 23998935, -2261715], [-2211072334, 0, 3401898188, 0, 3249512, 20800768, 11852244, -1148756, 0, 0, 0, 0], [-13162462263, 0, -1364394909, 0, 8384139, -1208289, -781067, 9712028, 0, 0, 0, 0], [0, 177686504294, 0, 1022019102, 0, 0, 0, 0, 7593014, -17605081, 4766176, 2286695], [0, -288729153550, 0, 2468952728, 0, 0, 0, 0, -25533746, -16699522, -25001552, -1384822], [166452915800, 0, 2654814322, 0, -1699772, -35977146, 86948, 3962822, 0, 0, 0, 0], [33808986528, 0, -509179369, 0, 13743845, 74560950, 27833885, -11980605, 0, 0, 0, 0], [339065007050, 0, 2456445192, 0, -7932242, 112702444, 59022428, -6828208, 0, 0, 0, 0], [0, 312591542671, 0, 351924295, 0, 0, 0, 0, -103732400, -21042358, 17212416, 6925958], [107541511803, 0, -2226821621, 0, 22139631, 25852049, 20048037, -11255418, 0, 0, 0, 0], [-104336379486, 0, -5793395922, 0, -137940, -61666950, 886930, -6941740, 0, 0, 0, 0], [0, -451171767275, 0, 2341349710, 0, 0, 0, 0, -27702495, -5852560, 32876090, 6765765], [351071292225, 0, 3916474489, 0, 17072416, -46052177, 24485056, 5435384, 0, 0, 0, 0], [0, 98010102167, 0, 3899470891, 0, 0, 0, 0, -124765980, -6255442, -8852696, -9545338], [488887079700, 0, 2902114096, 0, 6766714, 15974922, -100779576, -1162214, 0, 0, 0, 0], [593922233825, 0, 5213534833, 0, -26206354, -140962069, 2174136, 404554, 0, 0, 0, 0], [0, 60487293326, 0, -5365815128, 0, 0, 0, 0, 171689990, 23377881, -8841772, -6078741], [0, 34745981194, 0, -161445766, 0, 0, 0, 0, -120248670, -1426793, 69346416, -6810577], [563589711475, 0, 4998508449, 0, -30779301, -108440982, 3706084, 762551, 0, 0, 0, 0], [0, -736210363725, 0, 3877635396, 0, 0, 0, 0, -103085697, 13128246, -68764464, 14395521], [248809600058, 0, 6615590804, 0, 1912404, 191785848, 157084540, 7294356, 0, 0, 0, 0], [0, 780537505739, 0, -772679381, 0, 0, 0, 0, 69827100, -42883306, 11990912, 9948906], [0, -740182902075, 0, 3644316614, 0, 0, 0, 0, 13937077, -318476, 21489634, -12701351], [0, -32493713077, 0, 2090122863, 0, 0, 0, 0, 97044000, -65733222, 156640344, 18460722], [0, -545669796850, 0, 3165346726, 0, 0, 0, 0, 117378768, -65098258, -58964978, -5856958], [0, -56729397403, 0, 3356677981, 0, 0, 0, 0, -170335830, 97490078, -222416336, -16869958], [-124894987691, 0, -1715468633, 0, -63433173, 105453039, -75559615, 7436088, 0, 0, 0, 0], [0, -779535270876, 0, 2078247188, 0, 0, 0, 0, -178441890, 90990649, 24275312, -18112439], [-672130885912, 0, -360671972, 0, 89528332, -251952150, 47347036, -3963018, 0, 0, 0, 0], [0, 459670143443, 0, -3190685917, 0, 0, 0, 0, 105213825, -40870827, 195398504, 12827277], [600898977922, 0, 6311772414, 0, -63275400, -474395750, -64937950, 15830100, 0, 0, 0, 0], [1444377367500, 0, -2430317748, 0, 47676588, 55084914, -234127392, -13280388, 0, 0, 0, 0], [-1942095180717, 0, 5368758079, 0, 3409339, -326946747, -111928175, -42957114, 0, 0, 0, 0], [-1163435415625, 0, 5280331319, 0, -14416032, -298722867, 77847688, 29763432, 0, 0, 0, 0], [0, 112342643150, 0, -2478046629, 0, 0, 0, 0, 402996028, 63806919, -74753521, 58662669], [-35229373288, 0, 725001001, 0, 73279187, 303770930, -30293469, -25264043, 0, 0, 0, 0], [0, 208658464664, 0, -11503571186, 0, 0, 0, 0, -498796020, 11432597, -235040964, 11375683], [911919109100, 0, 8883019906, 0, 26856284, -217356808, -148227156, 24053266, 0, 0, 0, 0], [-1968172443799, 0, -7321187453, 0, 51993519, 203137435, 116601397, -37958016, 0, 0, 0, 0], [0, -15250618785, 0, -3108005705, 0, 0, 0, 0, 92367825, 107638685, 12861080, -50717235], [469799779225, 0, 2892377913, 0, 7071264, 215610441, 178706824, 11585936, 0, 0, 0, 0], [0, 322770375650, 0, 24043012831, 0, 0, 0, 0, 132426108, 56255843, 153021763, -37824007], [0, -238784141434, 0, -13388715042, 0, 0, 0, 0, -54990866, 4297947, 268670240, 45490587], [0, 1137011350550, 0, 2619268452, 0, 0, 0, 0, 312189236, 2762252, -80518268, 74090552], [731436618156, 0, 12280826563, 0, -79390469, 43679040, 52586153, 34261841, 0, 0, 0, 0], [0, 2986512412150, 0, -376577263, 0, 0, 0, 0, -569844234, -91972901, 57020309, -91827851], [0, 2022708326757, 0, 15894559033, 0, 0, 0, 0, 754751725, -91280169, -158833512, -55845981], [0, -1500030224118, 0, 23317816956, 0, 0, 0, 0, -328516038, -99299463, 168142388, -26250925], [0, 2684739112250, 0, 36713970030, 0, 0, 0, 0, -521567460, 26482830, 54565030, 16028830], [0, 1306876267225, 0, 12705387730, 0, 0, 0, 0, 262261365, 113175360, 380277310, -32217315], [-7258109742050, 0, 22500434948, 0, 156792902, -106887714, 72925132, -84748952, 0, 0, 0, 0], [-1118545994975, 0, 35254870437, 0, 4062446, 606754259, 36707536, -54486146, 0, 0, 0, 0], [0, 2750445410900, 0, 42781567126, 0, 0, 0, 0, -622940632, -79351596, -461456386, -50046846], [0, 2504086623302, 0, -12879688166, 0, 0, 0, 0, -29189820, -225585643, -16761784, -90443127], [-162605871525, 0, 25531005119, 0, -41138836, 373976583, 811497024, 117383336, 0, 0, 0, 0], [-5027876732950, 0, 11013721382, 0, 427500318, 569647524, -112765112, -62703018, 0, 0, 0, 0], [0, 2991736584950, 0, 21058139718, 0, 0, 0, 0, -405264526, 156459752, -157679018, 45834752], [-3474358708586, 0, -50905758648, 0, 88964668, -453939348, 25767816, 89088116, 0, 0, 0, 0], [-199274098994, 0, 260311378, 0, 16600978, 314335296, -555632410, 171779582, 0, 0, 0, 0], [0, 3431201614450, 0, 21951720813, 0, 0, 0, 0, 47527884, 205163133, 226308953, -37671517], [0, 148198340165, 0, -38646476255, 0, 0, 0, 0, -342751875, 202500335, -659176920, 129670915], [0, 4214503288150, 0, 6889242147, 0, 0, 0, 0, -267898104, 59744199, 205337159, 186716249], [-1425131468654, 0, 6172658876, 0, 324579652, -8755520, -656433324, -82035628, 0, 0, 0, 0], [0, -8314383562952, 0, 47286014588, 0, 0, 0, 0, -495020040, -208724801, 16476312, -64226389], [0, 1309907875250, 0, 17984133478, 0, 0, 0, 0, 2171294304, -58872082, 587942638, -151478782], [1879885489375, 0, 27794279957, 0, -227159411, 580541524, 145981524, -124710139, 0, 0, 0, 0], [0, -6520418608709, 0, -60613932801, 0, 0, 0, 0, -318674425, -12915117, 627791584, -172163433], [0, 3253153356150, 0, -2561178322, 0, 0, 0, 0, 994190054, -412149012, -327393042, -62528412], [3695797503250, 0, -33439908344, 0, -248873336, -1421330958, -1452662276, -68878314, 0, 0, 0, 0], [0, 807842229750, 0, 2293826583, 0, 0, 0, 0, -672769506, -212145591, -762825981, -129409041], [-9408084353960, 0, 60315381816, 0, -136643434, 609678200, -74748632, 267282616, 0, 0, 0, 0], [0, -4111066244628, 0, -25297784254, 0, 0, 0, 0, 863396424, -193811159, -333961508, -164227017], [-8683507633075, 0, -9908671811, 0, 282715702, 777526473, 481602032, -16909102, 0, 0, 0, 0], [0, -4799761035000, 0, -14179141720, 0, 0, 0, 0, 1598452090, 213551824, -733160816, -163248026], [-8231075441151, 0, -44537481567, 0, 182749241, 589306015, 346832783, -753674, 0, 0, 0, 0], [0, 11077350298065, 0, 33909198637, 0, 0, 0, 0, 3142095000, 19703108, 144118184, -208701108], [7421298383225, 0, 43078716205, 0, -190366772, 165041685, 633354848, -122934328, 0, 0, 0, 0], [0, -4516557249959, 0, 12848768993, 0, 0, 0, 0, 2759369910, -169802966, 419484792, 264971726], [-7972325397200, 0, -31124281630, 0, -197192710, -1772112960, -1317675260, 542990560, 0, 0, 0, 0], [20740985505500, 0, 33814527612, 0, 475121028, 1877010434, 436501648, 36941172, 0, 0, 0, 0], [-10338543077301, 0, 162921879, 0, -358361317, -1539035255, 1699337129, 85702738, 0, 0, 0, 0], [1710273017840, 0, -8146157681, 0, 639266509, 1043924250, -1491006443, -163322241, 0, 0, 0, 0], [0, -6812632766975, 0, 11894965904, 0, 0, 0, 0, 2484581397, 228539194, -1155509596, 300070519], [0, -6585161221003, 0, 12229907281, 0, 0, 0, 0, -1425259155, -578201797, -1949679536, -207883033], [17306261966830, 0, -42093630158, 0, -571886208, 789900150, 1311469166, 122078892, 0, 0, 0, 0], [28877595946525, 0, -50060802369, 0, -25454097, -171708308, -954749452, 356851647, 0, 0, 0, 0], [0, -11899776492458, 0, 34730731296, 0, 0, 0, 0, -2447192772, -410953501, -306259020, 318010829], [-6266445197664, 0, 46774711577, 0, 586206595, -5398577250, -1381033565, -82266655, 0, 0, 0, 0], [15003560581375, 0, 179795240855, 0, -650774482, -2079323415, 400336288, 185418682, 0, 0, 0, 0], [-6219510288350, 0, 76592238738, 0, -301402548, 1716458866, -1129219168, -508671852, 0, 0, 0, 0], [0, -17891206373400, 0, 142253327535, 0, 0, 0, 0, 1976546130, -308750313, 1453958667, 148216587]]
